@@ -58,6 +58,7 @@
 #include <xsh_model_io.h>
 #include <xsh_model_utils.h>
 #include <xsh_utils_ifu.h>
+#include <xsh_utils_scired_slit.h>
 #include <xsh_model_arm_constants.h>
 /* DRL functions */
 #include <xsh_drl.h>
@@ -463,8 +464,8 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   cpl_frame *spectral_format_frame = NULL;
   cpl_frame *ifu_cfg_tab_frame = NULL ;
   cpl_frame *ifu_cfg_cor_frame = NULL ;
-  int nobj=0;
-  int nsky=0;
+  //int nobj=0;
+  //int nsky=0;
 
   /* Input frames */
   cpl_frameset* raws = NULL;
@@ -509,8 +510,8 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   cpl_frameset * ext_frameset = NULL ;
   cpl_frameset * ext_frameset_tables = NULL ;
   char* prefix=NULL;
-  int i ;
-  char  file_name[256], arm_str[16] ;
+ 
+  char  arm_str[16] ;
   char  * file_tag = NULL;
   cpl_frame* grid_backg=NULL;
   cpl_frame* frame_backg=NULL;
@@ -520,12 +521,12 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   //cpl_frameset * rect_frameset_eso=NULL;
   char rec_prefix[256];
   char sky_prefix[256];
-  cpl_frame* object_frame=NULL;
+  //cpl_frame* object_frame=NULL;
   //int check_afc = TRUE;
   int do_compute_map = TRUE;
   int recipe_use_model = FALSE;
-  char wave_map_tag[256];
-  char slit_map_tag[256];
+  //char wave_map_tag[256];
+  //char slit_map_tag[256];
   cpl_frame *wavemap = NULL ;
   cpl_frame *slitmap = NULL ;
   cpl_frame *disp_tab_frame = NULL;
@@ -674,8 +675,8 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
 				   XSH_SKY_IFU, &raw_object,
 					   &raw_sky ) ) ;
 
-  nobj=cpl_frameset_get_size(raw_object);
-  nsky=cpl_frameset_get_size(raw_sky);
+  //nobj=cpl_frameset_get_size(raw_object);
+  //nsky=cpl_frameset_get_size(raw_sky);
   prefix=xsh_set_recipe_file_prefix(raws,"xsh_scired_ifu_offset");
   sprintf(sky_prefix,xsh_set_recipe_sky_file_prefix(rec_prefix));
   check(strcpy(rec_prefix,(const char*)prefix));
@@ -713,7 +714,7 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
 
 
 
-  check(object_frame=cpl_frameset_get_frame(raw_object,0));
+  //check(object_frame=cpl_frameset_get_frame(raw_object,0));
   if ( model_config_frame == NULL){
     xsh_msg("RECIPE USE WAVE SOLUTION");
     recipe_use_model = FALSE;
