@@ -571,7 +571,7 @@ xsh_badpixelmap_image_coadd(cpl_image **self, const cpl_image *right, const int
   pself=cpl_image_get_data_int(*self);
   pright=cpl_image_get_data_int_const(right);
   if(mode) {
-     xsh_msg("Bitwise OR combine"); 
+     //xsh_msg("Bitwise OR combine");
      for(j=0;j<ny;j++) {
         j_nx=j*nx;
         for(i=0;i<nx;i++) {
@@ -581,7 +581,7 @@ xsh_badpixelmap_image_coadd(cpl_image **self, const cpl_image *right, const int
         }
      }
   } else {
-     xsh_msg("Bitwise AND combine"); 
+     //xsh_msg("Bitwise AND combine");
      for(j=0;j<ny;j++) {
         j_nx=j*nx;
         for(i=0;i<nx;i++) {
@@ -1191,7 +1191,6 @@ xsh_count_crh(xsh_pre* pre, xsh_instrument* instr,const int datancom)
 {
     int* pqual=NULL;
     int size;
-    int bp_code_sat=0;
     int ncrh=0;
     int i=0;
 
