@@ -543,6 +543,60 @@ int* xsh_spectrum_get_qual( xsh_spectrum* s)
 
 /*---------------------------------------------------------------------------*/
 /** 
+ * @brief Get flux of spectrum as image
+ *
+ * @param[in] s spectrum structure
+ *
+ * @return the flux data of spectrum
+ */
+/*---------------------------------------------------------------------------*/
+cpl_image* xsh_spectrum_get_flux_ima( xsh_spectrum* s)
+{
+
+  XSH_ASSURE_NOT_NULL( s);
+
+  cleanup:
+    return s->flux;
+}
+
+/*---------------------------------------------------------------------------*/
+/**
+ * @brief Get flux of spectrum as image
+ *
+ * @param[in] s spectrum structure
+ *
+ * @return the flux data of spectrum
+ */
+/*---------------------------------------------------------------------------*/
+cpl_image* xsh_spectrum_get_errs_ima( xsh_spectrum* s)
+{
+
+  XSH_ASSURE_NOT_NULL( s);
+
+  cleanup:
+    return s->errs;
+}
+
+
+/*---------------------------------------------------------------------------*/
+/**
+ * @brief Get flux of spectrum as image
+ *
+ * @param[in] s spectrum structure
+ *
+ * @return the flux data of spectrum
+ */
+/*---------------------------------------------------------------------------*/
+cpl_image* xsh_spectrum_get_qual_ima( xsh_spectrum* s)
+{
+
+  XSH_ASSURE_NOT_NULL( s);
+
+  cleanup:
+    return s->qual;
+}
+/*---------------------------------------------------------------------------*/
+/**
  * @brief free memory associated to an 1D spectrum
  * 
  * @param[in] s spectrum structure to free
@@ -646,10 +700,10 @@ cpl_frame* xsh_spectrum_save( xsh_spectrum* s, const char* filename,
 
 
 
-    check(xsh_pfits_set_wcs1(s->errs_header, crpix1, crval1, crpix1));
+    check(xsh_pfits_set_wcs1(s->errs_header, crpix1, crval1, cdelt1));
     xsh_pfits_set_cunit1(s->errs_header,"nm");
 
-    check(xsh_pfits_set_wcs1(s->qual_header, crpix1, crval1, crpix1));
+    check(xsh_pfits_set_wcs1(s->qual_header, crpix1, crval1, cdelt1));
     xsh_pfits_set_cunit1(s->qual_header,"nm");
     xsh_pfits_set_bunit(s->qual_header,XSH_BUNIT_NONE_C);
 
