@@ -176,7 +176,7 @@ xsh_dump_sky_fit(const int level, const char* sarm,
     pentry = wave_list->list[idx].sky;
     for (int i = 0; i < nitem; i++, pentry++) {
         double yerr = 0;
-        double xi = pentry->lambda;
+        //double xi = pentry->lambda;
         double yi = yf[i];
         pentry->fitted = yi;
         pentry->fit_err = yerr;
@@ -774,7 +774,7 @@ xsh_wavemap_list_new( cpl_image *wavemap, cpl_image *slitmap,
                       xsh_instrument *instrument)
 {
     xsh_wavemap_list *wave_list = NULL;
-    int i, nx, ny, max_size, sky_size;
+    int i, nx, max_size, sky_size;
     int iorder ;
 
     int nrow=0;
@@ -803,7 +803,7 @@ xsh_wavemap_list_new( cpl_image *wavemap, cpl_image *slitmap,
 
     /* order position */
     nx = xsh_pre_get_nx( pre_sci);
-    ny = xsh_pre_get_ny( pre_sci);
+    //ny = xsh_pre_get_ny( pre_sci);
 
     if( xsh_instrument_get_arm(instrument) == XSH_ARM_NIR){
         wmap_xsize_diff=pre_sci->nx-cpl_image_get_size_x(slitmap);
@@ -988,8 +988,8 @@ xsh_wavemap_list_build_sky(xsh_wavemap_list* wave_list, xsh_instrument* instr) {
     double *lambdas = NULL;
     float *sky_flux = NULL;
     float *sky_err = NULL;
-    float* pflat = NULL;
-    int sx = 0;
+    //float* pflat = NULL;
+    //int sx = 0;
     psky = wave_list->list[i].sky;
     sky_size = wave_list->list[i].sky_size;
     order = wave_list->list[i].order;
@@ -1188,8 +1188,8 @@ xsh_wavelist_subtract_sky(xsh_pre * pre_sci, xsh_rec_list* sky_list,
   float* perrs = NULL;
   float* pflux = NULL;
   float* pflat = NULL;
-  int* pqual = NULL;
-  int nx, ny;
+  //int* pqual = NULL;
+  int nx;
   xsh_pre* pre_res = NULL;
   cpl_image* res_image = NULL;
   cpl_frame* res_frame = NULL;
@@ -1206,10 +1206,10 @@ xsh_wavelist_subtract_sky(xsh_pre * pre_sci, xsh_rec_list* sky_list,
   check( res_image = xsh_pre_get_data( pre_res));
   check( pflux = cpl_image_get_data_float( res_image));
   check( perrs = cpl_image_get_data_float( xsh_pre_get_errs( pre_res)));
-  check( pqual = cpl_image_get_data_int( xsh_pre_get_qual( pre_res)));
+  //check( pqual = cpl_image_get_data_int( xsh_pre_get_qual( pre_res)));
 
   nx = xsh_pre_get_nx(pre_res);
-  ny = xsh_pre_get_ny(pre_res);
+  //ny = xsh_pre_get_ny(pre_res);
 
   for (iorder = 0; iorder < wave_list->size; iorder++) {
     wavemap_item* psky = NULL;
