@@ -1619,11 +1619,6 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
     double cube_wave_min=0;
     double cube_wave_max=0;
 
-
-    int qual_upp=0;
-    int qual_cen=0;
-    int qual_low=0;
-
     //double cube_wmin=550;
     //double cube_wmax=1000;
     double cube_wstep=0;
@@ -1881,7 +1876,13 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
     check(data_img=cpl_image_load(sci_name,XSH_PRE_DATA_TYPE,0,0));
     check(errs_img=cpl_image_load(sci_name,XSH_PRE_ERRS_TYPE,0,1));
     check(qual_img=cpl_image_load(sci_name,XSH_PRE_QUAL_TYPE,0,2));
-
+    int nx=cpl_image_get_size_x(data_img);
+    int ny=cpl_image_get_size_y(data_img);
+    int* pqual_img=cpl_image_get_data_int(qual_img);
+    cpl_image* var_img=cpl_image_duplicate(data_img);
+    cpl_image_power(var_img,2.);
+    cpl_vector* profile2=cpl_vector_duplicate(profile);
+    cpl_vector_power(profile2,2.);
     check(sp_fmt_name=cpl_frame_get_filename(spectral_format_frame));
     check(sp_fmt_tab=cpl_table_load(sp_fmt_name,1,0));
     check(ord_min=cpl_table_get_column_min(sp_fmt_tab,"ORDER"));
@@ -1921,7 +1922,7 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
     xsh_free_image(&errs_tmp);
     xsh_free_image(&qual_tmp);
     xsh_free_image(&mask_tmp);
-
+    //double var_low=0, var_cen=0, var_upp=0;
     mk=0;
 
     for( ord = ord_max; ord >= ord_min; ord-- ) {
@@ -1965,7 +1966,9 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
         for( wave = wave_min; wave <= wave_max; wave+=wave_step) {
             is=0;
             for( s = s_min; s <= s_max; s+=s_step ) {
-
+                int qual_upp=0;
+                int qual_cen=0;
+                int qual_low=0;
                 /* upper slice */
                 s_upp=-s+s_upp_off+w_upp_coeff1*wave+w_upp_coeff2*wave*wave;
                 s_upp-=(s_upp_d0+s_upp_d1*wave+s_upp_d2*wave*wave)*s_step;
@@ -1984,20 +1987,46 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
                                 profile,radius,
                                 profile,radius,
                                 &confidence));
-                check(errs_upp=cpl_image_get_interpolated(errs_img,x,y,
-                                profile,radius,
-                                profile,radius,
-                                &confidence));
-                check(qual_upp=cpl_image_get_interpolated(qual_img,x,y,
-                                profile,radius,
-                                profile,radius,
-                                &confidence));
+                
+                if (confidence <= 0) {
+                    pima[is*naxis1+0]=0;
+                    perr[is*naxis1+0]=1;
+                    pqua[is*naxis1+0]=QFLAG_MISSING_DATA;
+                    pmsk[is*naxis1+0]=1;
+                    /* If flux interpolation ok */
+                } else {
 
-                pima[is*naxis1+0]=flux_upp;
-                perr[is*naxis1+0]=errs_upp;
-                pqua[is*naxis1+0]=qual_upp;
-                pmsk[is*naxis1+0]=1;
+                    check(errs_upp=cpl_image_get_interpolated(errs_img,x,y,
+                                    profile,radius,
+                                    profile,radius,
+                                    &confidence));
+                    /*
+                    if(confidence > 0 && var_upp>0) {
+                    errs_upp=sqrt(var_upp);
+                    } else {
+                        errs_upp=0;
+                    }
+                    */
+                    /* Now propagate flags */
+                    int ix=(int)(x+0.5);
+                    int iy=(int)(x+0.5);
+                    int jj_nx=0;
+                    int jj_min= ( iy - radius >= 0 ) ? iy - radius: 0;
+                    int jj_max= ( iy + radius < ny ) ? iy + radius: 0;
+                    //int ii_min= ( ix - radius >= 0 ) ? ix - radius: 0;
+                    //int ii_max= ( ix + radius < nx ) ? ix + radius: 0;
+                    for(int jj=jj_min;jj<jj_max;jj++) {
+                        jj_nx=jj*nx;
+                        for(int ii=ix-radius;ii<ix+radius-1;ii++) {
+                            qual_upp |= pqual_img[jj_nx+ii];         //UMR
+                        }
+                    }
 
+                    pima[is*naxis1+0]=flux_upp;
+                    perr[is*naxis1+0]=errs_upp;
+                    pqua[is*naxis1+0]=qual_upp;
+                    pmsk[is*naxis1+0]=1;
+                }
                 /* central slice */
                 if(wavesol!=NULL) {
                     check( x= xsh_wavesol_eval_polx( wavesol,wave, ord,s));
@@ -2006,26 +2035,53 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
                     check(xsh_model_get_xy(&model_config,instrument,wave,ord,s,
                                     &x,&y));
                 }
+
+
                 check(flux_cen=cpl_image_get_interpolated(data_img,x,y,
-                                profile,radius,
-                                profile,radius,
-                                &confidence));
+                                               profile,radius,
+                                               profile,radius,
+                                               &confidence));
+              
+                if (confidence <= 0) {
+                    pima[is*naxis1+1]=0;
+                    perr[is*naxis1+1]=1;
+                    pqua[is*naxis1+1]=QFLAG_MISSING_DATA;
+                    pmsk[is*naxis1+1]=1;
+                    /* If flux interpolation ok */
+                } else {
 
-                check(errs_cen=cpl_image_get_interpolated(errs_img,x,y,
-                                profile,radius,
-                                profile,radius,
-                                &confidence));
-
-                check(qual_cen=cpl_image_get_interpolated(qual_img,x,y,
-                                profile,radius,
-                                profile,radius,
-                                &confidence));
-
-                pima[is*naxis1+1]=flux_cen;
-                perr[is*naxis1+1]=errs_cen;
-                pqua[is*naxis1+1]=qual_cen;
-                pmsk[is*naxis1+1]=1;
+                    check(errs_cen=cpl_image_get_interpolated(errs_img,x,y,
+                                    profile,radius,
+                                    profile,radius,
+                                    &confidence));
+                    /*
+                    if(confidence > 0 && var_cen>0) {
+                    errs_cen=sqrt(var_cen);
+                    } else {
+                        errs_cen=0;
+                    }
+		    */
+                   
+                    /* Now propagate flags */
+                    int ix=(int)(x+0.5);
+                    int iy=(int)(x+0.5);
+                    int jj_nx=0;
+                    int jj_min= ( iy - radius >= 0 ) ? iy - radius: 0;
+                    int jj_max= ( iy + radius < ny ) ? iy + radius: 0;
+                    //int ii_min= ( ix - radius >= 0 ) ? ix - radius: 0;
+                    //int ii_max= ( ix + radius < nx ) ? ix + radius: 0;
+                    for(int jj=jj_min;jj<jj_max;jj++) {
+                        jj_nx=jj*nx;
+                        for(int ii=ix-radius;ii<ix+radius-1;ii++) {
+                            qual_cen |= pqual_img[jj_nx+ii];         //UMR
+                        }
+                    }
 
+                    pima[is*naxis1+1]=flux_cen;
+                    perr[is*naxis1+1]=errs_cen;
+                    pqua[is*naxis1+1]=qual_cen;
+                    pmsk[is*naxis1+1]=1;
+                }
                 /* lower slice */
                 s_low=-s+s_low_off+w_low_coeff1*wave+w_low_coeff2*wave*wave;
                 s_low-=(s_low_d0+s_low_d1*wave+s_low_d2*wave*wave)*s_step;
@@ -2042,20 +2098,47 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
                                 profile,radius,
                                 profile,radius,
                                 &confidence));
-                check(errs_low=cpl_image_get_interpolated(errs_img,x,y,
-                                profile,radius,
-                                profile,radius,
-                                &confidence));
-                check(qual_low=cpl_image_get_interpolated(qual_img,x,y,
-                                profile,radius,
-                                profile,radius,
-                                &confidence));
+               
+                if (confidence <= 0 ) {
+                     pima[is*naxis1+2]=0;
+                     perr[is*naxis1+2]=1;
+                     pqua[is*naxis1+2]=QFLAG_MISSING_DATA;
+                     pmsk[is*naxis1+2]=1;
+                     /* If flux interpolation ok */
+                } else {
 
-                pima[is*naxis1+2]=flux_low;
-                perr[is*naxis1+2]=errs_low;
-                pqua[is*naxis1+2]=qual_low;
-                pmsk[is*naxis1+2]=1;
+                    check(errs_low=cpl_image_get_interpolated(errs_img,x,y,
+                                    profile,radius,
+                                    profile,radius,
+                                    &confidence));
+                    /*
+                    if(var_low>0 ) {
+                    errs_low=sqrt(confidence > 0 && var_low);
+                    } else {
+                        errs_low=0;
+                    }
+		    */
+                    
+                    /* Now propagate flags */
+                    int ix=(int)(x+0.5);
+                    int iy=(int)(x+0.5);
+                    int jj_nx=0;
+                    int jj_min= ( iy - radius >= 0 ) ? iy - radius: 0;
+                    int jj_max= ( iy + radius < ny ) ? iy + radius: 0;
+                    //int ii_min= ( ix - radius >= 0 ) ? ix - radius: 0;
+                    //int ii_max= ( ix + radius < nx ) ? ix + radius: 0;
+                    for(int jj=jj_min;jj<jj_max;jj++) {
+                        jj_nx=jj*nx;
+                        for(int ii=ix-radius;ii<ix+radius-1;ii++) {
+                            qual_low |= pqual_img[jj_nx+ii];         //UMR
+                        }
+                    }
 
+                    pima[is*naxis1+2]=flux_low;
+                    perr[is*naxis1+2]=errs_low;
+                    pqua[is*naxis1+2]=qual_low;
+                    pmsk[is*naxis1+2]=1;
+                }
 
                 is++;
             } /* end loop on s */
@@ -2066,14 +2149,17 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
             check(cpl_imagelist_set(errs_cube,cpl_image_duplicate(errs_tmp),ik));
             check(cpl_imagelist_set(qual_cube,cpl_image_duplicate(qual_tmp),ik));
 
+            /*
             check(xsh_iml_merge_avg(&data_cube_merge,&mask_data_merge,
                             data_tmp,mask_tmp,mk));
             check(xsh_iml_merge_avg(&errs_cube_merge,&mask_errs_merge,
                             errs_tmp,mask_tmp,mk));
             check(xsh_iml_merge_avg(&qual_cube_merge,&mask_qual_merge,
                             qual_tmp,mask_tmp,mk));
-
-
+            */
+            check(xsh_iml_merge_wgt(&data_cube_merge, &errs_cube_merge, &qual_cube_merge,
+                              data_tmp, errs_tmp, qual_tmp, mk,
+                              instrument->decode_bp));
             ik++;
             if(ord==ord_max) {
                 mk++;
@@ -2089,15 +2175,15 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
             xsh_add_temporary_file(name);
         }
         xsh_cube_set_wcs(data_plist,wave_min,
-                         2.,s_step,wave_step,
+                         0.6,s_step,wave_step,
                          1,naxis2/2.,0);
 
         xsh_cube_set_wcs(errs_plist,wave_min,
-                         2.,s_step,wave_step,
+                         0.6,s_step,wave_step,
                          1,naxis2/2.,0);
 
         xsh_cube_set_wcs(qual_plist,wave_min,
-                         2.,s_step,wave_step,
+                         0.6,s_step,wave_step,
                          1,naxis2/2.,0);
 
         sprintf(data_extid,"ORD%2.2d_FLUX",ord);
@@ -2144,15 +2230,15 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
             xsh_arm_tostring(arm));
     sprintf(name,"%s.fits",tag);
     xsh_cube_set_wcs(data_plist,cube_wave_min,
-                     2.,s_step,wave_step,
+                     0.6,s_step,wave_step,
                      1,naxis2/2.,0);
 
     xsh_cube_set_wcs(errs_plist,cube_wave_min,
-                     2.,s_step,wave_step,
+                     0.6,s_step,wave_step,
                      1,naxis2/2.,0);
 
     xsh_cube_set_wcs(qual_plist,cube_wave_min,
-                     2.,s_step,wave_step,
+                     0.6,s_step,wave_step,
                      1,naxis2/2.,0);
 
     sprintf(data_extid,"FLUX");
@@ -2246,7 +2332,8 @@ xsh_build_ifu_cube(cpl_frame* div_frame,
     xsh_free_image(&errs_img);
     xsh_free_image(&qual_img);
 
-
+    xsh_free_image(&var_img);
+    xsh_free_vector(&profile2);
     xsh_free_table(&sp_fmt_tab);
 
     xsh_free_imagelist(&data_cube);
