@@ -1313,7 +1313,6 @@ xsh_respon_slit_nod_get_calibs(cpl_frameset* calib,
 
 {
   int recipe_use_model=FALSE;
-  cpl_frame* ref_frame=NULL;
   cpl_boolean mode_phys;
   mode_phys=xsh_mode_is_physmod(calib,instrument);
   check(*bpmap=xsh_check_load_master_bpmap(calib,instrument,recipe_id));
@@ -1604,8 +1603,6 @@ xsh_ifu_stare_get_calibs(cpl_frameset* calib,
                           int pscan)
 {
 
-    cpl_boolean mode_phys;
-    mode_phys=xsh_mode_is_physmod(calib,inst);
     check(*spectral_format = xsh_find_spectral_format( calib, inst));
 
     XSH_ASSURE_NOT_NULL_MSG(*spectral_format,"Null input spectral format frame");
